(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common/http')) :
    typeof define === 'function' && define.amd ? define('@singletonar/tlc-api-angular-client', ['exports', '@angular/core', '@angular/common/http'], factory) :
    (global = global || self, factory((global.singletonar = global.singletonar || {}, global.singletonar['tlc-api-angular-client'] = {}), global.ng.core, global.ng.common.http));
}(this, function (exports, core, http) { 'use strict';

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */
    /* global Reflect, Promise */

    var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };

    function __extends(d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }

    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }

    function __param(paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); }
    }

    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
    }

    function __values(o) {
        var m = typeof Symbol === "function" && o[Symbol.iterator], i = 0;
        if (m) return m.call(o);
        return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
    }

    /**
    * CustomHttpUrlEncodingCodec
    * Fix plus sign (+) not encoding, so sent as blank space
    * See: https://github.com/angular/angular/issues/11058#issuecomment-247367318
    */
    var CustomHttpUrlEncodingCodec = /** @class */ (function (_super) {
        __extends(CustomHttpUrlEncodingCodec, _super);
        function CustomHttpUrlEncodingCodec() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        CustomHttpUrlEncodingCodec.prototype.encodeKey = function (k) {
            k = _super.prototype.encodeKey.call(this, k);
            return k.replace(/\+/gi, '%2B');
        };
        CustomHttpUrlEncodingCodec.prototype.encodeValue = function (v) {
            v = _super.prototype.encodeValue.call(this, v);
            return v.replace(/\+/gi, '%2B');
        };
        return CustomHttpUrlEncodingCodec;
    }(http.HttpUrlEncodingCodec));

    var BASE_PATH = new core.InjectionToken('basePath');
    var COLLECTION_FORMATS = {
        'csv': ',',
        'tsv': '   ',
        'ssv': ' ',
        'pipes': '|'
    };

    var Configuration = /** @class */ (function () {
        function Configuration(configurationParameters) {
            if (configurationParameters === void 0) { configurationParameters = {}; }
            this.apiKeys = configurationParameters.apiKeys;
            this.username = configurationParameters.username;
            this.password = configurationParameters.password;
            this.accessToken = configurationParameters.accessToken;
            this.basePath = configurationParameters.basePath;
            this.withCredentials = configurationParameters.withCredentials;
        }
        /**
         * Select the correct content-type to use for a request.
         * Uses {@link Configuration#isJsonMime} to determine the correct content-type.
         * If no content type is found return the first found type if the contentTypes is not empty
         * @param contentTypes - the array of content types that are available for selection
         * @returns the selected content-type or <code>undefined</code> if no selection could be made.
         */
        Configuration.prototype.selectHeaderContentType = function (contentTypes) {
            var _this = this;
            if (contentTypes.length == 0) {
                return undefined;
            }
            var type = contentTypes.find(function (x) { return _this.isJsonMime(x); });
            if (type === undefined) {
                return contentTypes[0];
            }
            return type;
        };
        /**
         * Select the correct accept content-type to use for a request.
         * Uses {@link Configuration#isJsonMime} to determine the correct accept content-type.
         * If no content type is found return the first found type if the contentTypes is not empty
         * @param accepts - the array of content types that are available for selection.
         * @returns the selected content-type or <code>undefined</code> if no selection could be made.
         */
        Configuration.prototype.selectHeaderAccept = function (accepts) {
            var _this = this;
            if (accepts.length == 0) {
                return undefined;
            }
            var type = accepts.find(function (x) { return _this.isJsonMime(x); });
            if (type === undefined) {
                return accepts[0];
            }
            return type;
        };
        /**
         * Check if the given MIME is a JSON MIME.
         * JSON MIME examples:
         *   application/json
         *   application/json; charset=UTF8
         *   APPLICATION/JSON
         *   application/vnd.company+json
         * @param mime - MIME (Multipurpose Internet Mail Extensions)
         * @return True if the given MIME is JSON, false otherwise.
         */
        Configuration.prototype.isJsonMime = function (mime) {
            var jsonMime = new RegExp('^(application\/json|[^;/ \t]+\/[^;/ \t]+[+]json)[ \t]*(;.*)?$', 'i');
            return mime != null && (jsonMime.test(mime) || mime.toLowerCase() === 'application/json-patch+json');
        };
        return Configuration;
    }());

    var AccountEmailsService = /** @class */ (function () {
        function AccountEmailsService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        AccountEmailsService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        AccountEmailsService.prototype.addAccountEmails = function (accountEmail, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (accountEmail === null || accountEmail === undefined) {
                throw new Error('Required parameter accountEmail was null or undefined when calling addAccountEmails.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.post(this.basePath + "/accountEmails", accountEmail, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        AccountEmailsService.prototype.deleteAccountEmail = function (id, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling deleteAccountEmail.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.delete(this.basePath + "/accountEmails/" + encodeURIComponent(String(id)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        AccountEmailsService.prototype.editAccountEmail = function (accountEmail, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (accountEmail === null || accountEmail === undefined) {
                throw new Error('Required parameter accountEmail was null or undefined when calling editAccountEmail.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.put(this.basePath + "/accountEmails", accountEmail, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        AccountEmailsService.prototype.getAccountEmailById = function (id, deleted, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling getAccountEmailById.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/accountEmails/" + encodeURIComponent(String(id)), {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        AccountEmailsService.prototype.getAccountEmails = function (skip, limit, orderBy, filter, deleted, metadata, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (skip === null || skip === undefined) {
                throw new Error('Required parameter skip was null or undefined when calling getAccountEmails.');
            }
            if (limit === null || limit === undefined) {
                throw new Error('Required parameter limit was null or undefined when calling getAccountEmails.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (skip !== undefined && skip !== null) {
                queryParameters = queryParameters.set('skip', skip);
            }
            if (limit !== undefined && limit !== null) {
                queryParameters = queryParameters.set('limit', limit);
            }
            if (orderBy !== undefined && orderBy !== null) {
                queryParameters = queryParameters.set('orderBy', orderBy);
            }
            if (filter !== undefined && filter !== null) {
                queryParameters = queryParameters.set('filter', filter);
            }
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (metadata !== undefined && metadata !== null) {
                queryParameters = queryParameters.set('metadata', metadata);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/accountEmails", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        AccountEmailsService.ngInjectableDef = core.defineInjectable({ factory: function AccountEmailsService_Factory() { return new AccountEmailsService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: AccountEmailsService, providedIn: "root" });
        AccountEmailsService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], AccountEmailsService);
        return AccountEmailsService;
    }());

    var AccountsService = /** @class */ (function () {
        function AccountsService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        AccountsService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        AccountsService.prototype.addAccount = function (account, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (account === null || account === undefined) {
                throw new Error('Required parameter account was null or undefined when calling addAccount.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.post(this.basePath + "/accounts", account, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        AccountsService.prototype.deleteAccount = function (id, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling deleteAccount.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.delete(this.basePath + "/accounts/" + encodeURIComponent(String(id)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        AccountsService.prototype.editAccount = function (account, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (account === null || account === undefined) {
                throw new Error('Required parameter account was null or undefined when calling editAccount.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.put(this.basePath + "/accounts", account, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        AccountsService.prototype.getAccountById = function (id, deleted, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling getAccountById.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/accounts/" + encodeURIComponent(String(id)), {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        AccountsService.prototype.getAccounts = function (skip, limit, orderBy, filter, deleted, metadata, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (skip === null || skip === undefined) {
                throw new Error('Required parameter skip was null or undefined when calling getAccounts.');
            }
            if (limit === null || limit === undefined) {
                throw new Error('Required parameter limit was null or undefined when calling getAccounts.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (skip !== undefined && skip !== null) {
                queryParameters = queryParameters.set('skip', skip);
            }
            if (limit !== undefined && limit !== null) {
                queryParameters = queryParameters.set('limit', limit);
            }
            if (orderBy !== undefined && orderBy !== null) {
                queryParameters = queryParameters.set('orderBy', orderBy);
            }
            if (filter !== undefined && filter !== null) {
                queryParameters = queryParameters.set('filter', filter);
            }
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (metadata !== undefined && metadata !== null) {
                queryParameters = queryParameters.set('metadata', metadata);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/accounts", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        AccountsService.ngInjectableDef = core.defineInjectable({ factory: function AccountsService_Factory() { return new AccountsService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: AccountsService, providedIn: "root" });
        AccountsService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], AccountsService);
        return AccountsService;
    }());

    var CarriersService = /** @class */ (function () {
        function CarriersService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        CarriersService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        CarriersService.prototype.addCarrier = function (carrier, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (carrier === null || carrier === undefined) {
                throw new Error('Required parameter carrier was null or undefined when calling addCarrier.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.post(this.basePath + "/carriers", carrier, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        CarriersService.prototype.deleteCarrier = function (id, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling deleteCarrier.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.delete(this.basePath + "/carriers/" + encodeURIComponent(String(id)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        CarriersService.prototype.editCarrier = function (carrier, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (carrier === null || carrier === undefined) {
                throw new Error('Required parameter carrier was null or undefined when calling editCarrier.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.put(this.basePath + "/carriers", carrier, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        CarriersService.prototype.getCarrierById = function (id, deleted, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling getCarrierById.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/carriers/" + encodeURIComponent(String(id)), {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        CarriersService.prototype.getCarriers = function (skip, limit, orderBy, filter, deleted, metadata, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (skip === null || skip === undefined) {
                throw new Error('Required parameter skip was null or undefined when calling getCarriers.');
            }
            if (limit === null || limit === undefined) {
                throw new Error('Required parameter limit was null or undefined when calling getCarriers.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (skip !== undefined && skip !== null) {
                queryParameters = queryParameters.set('skip', skip);
            }
            if (limit !== undefined && limit !== null) {
                queryParameters = queryParameters.set('limit', limit);
            }
            if (orderBy !== undefined && orderBy !== null) {
                queryParameters = queryParameters.set('orderBy', orderBy);
            }
            if (filter !== undefined && filter !== null) {
                queryParameters = queryParameters.set('filter', filter);
            }
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (metadata !== undefined && metadata !== null) {
                queryParameters = queryParameters.set('metadata', metadata);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/carriers", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        CarriersService.ngInjectableDef = core.defineInjectable({ factory: function CarriersService_Factory() { return new CarriersService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: CarriersService, providedIn: "root" });
        CarriersService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], CarriersService);
        return CarriersService;
    }());

    var DeliveriesService = /** @class */ (function () {
        function DeliveriesService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        DeliveriesService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        DeliveriesService.prototype.addDelivery = function (delivery, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (delivery === null || delivery === undefined) {
                throw new Error('Required parameter delivery was null or undefined when calling addDelivery.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.post(this.basePath + "/deliveries", delivery, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        DeliveriesService.prototype.deleteDelivery = function (id, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling deleteDelivery.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.delete(this.basePath + "/deliveries/" + encodeURIComponent(String(id)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        DeliveriesService.prototype.editDelivery = function (delivery, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (delivery === null || delivery === undefined) {
                throw new Error('Required parameter delivery was null or undefined when calling editDelivery.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.put(this.basePath + "/deliveries", delivery, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        DeliveriesService.prototype.getDeliveries = function (skip, limit, orderBy, filter, deleted, metadata, idUser, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (skip === null || skip === undefined) {
                throw new Error('Required parameter skip was null or undefined when calling getDeliveries.');
            }
            if (limit === null || limit === undefined) {
                throw new Error('Required parameter limit was null or undefined when calling getDeliveries.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (skip !== undefined && skip !== null) {
                queryParameters = queryParameters.set('skip', skip);
            }
            if (limit !== undefined && limit !== null) {
                queryParameters = queryParameters.set('limit', limit);
            }
            if (orderBy !== undefined && orderBy !== null) {
                queryParameters = queryParameters.set('orderBy', orderBy);
            }
            if (filter !== undefined && filter !== null) {
                queryParameters = queryParameters.set('filter', filter);
            }
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (metadata !== undefined && metadata !== null) {
                queryParameters = queryParameters.set('metadata', metadata);
            }
            if (idUser !== undefined && idUser !== null) {
                queryParameters = queryParameters.set('idUser', idUser);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/deliveries", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        DeliveriesService.prototype.getDeliveryById = function (id, deleted, idUser, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling getDeliveryById.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (idUser !== undefined && idUser !== null) {
                queryParameters = queryParameters.set('idUser', idUser);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/deliveries/" + encodeURIComponent(String(id)), {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        DeliveriesService.ngInjectableDef = core.defineInjectable({ factory: function DeliveriesService_Factory() { return new DeliveriesService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: DeliveriesService, providedIn: "root" });
        DeliveriesService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], DeliveriesService);
        return DeliveriesService;
    }());

    var EmailsService = /** @class */ (function () {
        function EmailsService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        EmailsService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        EmailsService.prototype.sendEmail = function (data, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (data === null || data === undefined) {
                throw new Error('Required parameter data was null or undefined when calling sendEmail.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.post(this.basePath + "/users/email/request", data, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        EmailsService.prototype.verifyEmail = function (token, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (token === null || token === undefined) {
                throw new Error('Required parameter token was null or undefined when calling verifyEmail.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/users/email/verify/" + encodeURIComponent(String(token)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        EmailsService.ngInjectableDef = core.defineInjectable({ factory: function EmailsService_Factory() { return new EmailsService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: EmailsService, providedIn: "root" });
        EmailsService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], EmailsService);
        return EmailsService;
    }());

    var HandedOversService = /** @class */ (function () {
        function HandedOversService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        HandedOversService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        HandedOversService.prototype.addHandedOver = function (handedOver, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (handedOver === null || handedOver === undefined) {
                throw new Error('Required parameter handedOver was null or undefined when calling addHandedOver.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.post(this.basePath + "/handedOvers", handedOver, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        HandedOversService.prototype.deleteHandedOver = function (id, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling deleteHandedOver.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.delete(this.basePath + "/handedOvers/" + encodeURIComponent(String(id)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        HandedOversService.prototype.editHandedOver = function (handedOver, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (handedOver === null || handedOver === undefined) {
                throw new Error('Required parameter handedOver was null or undefined when calling editHandedOver.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.put(this.basePath + "/handedOvers", handedOver, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        HandedOversService.prototype.getHandedOverById = function (id, deleted, idUser, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling getHandedOverById.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (idUser !== undefined && idUser !== null) {
                queryParameters = queryParameters.set('idUser', idUser);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/handedOvers/" + encodeURIComponent(String(id)), {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        HandedOversService.prototype.getHandedOvers = function (skip, limit, orderBy, filter, deleted, metadata, idUser, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (skip === null || skip === undefined) {
                throw new Error('Required parameter skip was null or undefined when calling getHandedOvers.');
            }
            if (limit === null || limit === undefined) {
                throw new Error('Required parameter limit was null or undefined when calling getHandedOvers.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (skip !== undefined && skip !== null) {
                queryParameters = queryParameters.set('skip', skip);
            }
            if (limit !== undefined && limit !== null) {
                queryParameters = queryParameters.set('limit', limit);
            }
            if (orderBy !== undefined && orderBy !== null) {
                queryParameters = queryParameters.set('orderBy', orderBy);
            }
            if (filter !== undefined && filter !== null) {
                queryParameters = queryParameters.set('filter', filter);
            }
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (metadata !== undefined && metadata !== null) {
                queryParameters = queryParameters.set('metadata', metadata);
            }
            if (idUser !== undefined && idUser !== null) {
                queryParameters = queryParameters.set('idUser', idUser);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/handedOvers", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        HandedOversService.ngInjectableDef = core.defineInjectable({ factory: function HandedOversService_Factory() { return new HandedOversService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: HandedOversService, providedIn: "root" });
        HandedOversService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], HandedOversService);
        return HandedOversService;
    }());

    var JourneyDeliveriesService = /** @class */ (function () {
        function JourneyDeliveriesService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        JourneyDeliveriesService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        JourneyDeliveriesService.prototype.addJourneyDelivery = function (journeyDelivery, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (journeyDelivery === null || journeyDelivery === undefined) {
                throw new Error('Required parameter journeyDelivery was null or undefined when calling addJourneyDelivery.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.post(this.basePath + "/journeyDeliveries", journeyDelivery, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        JourneyDeliveriesService.prototype.deleteJourneyDelivery = function (id, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling deleteJourneyDelivery.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.delete(this.basePath + "/journeyDeliveries/" + encodeURIComponent(String(id)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        JourneyDeliveriesService.prototype.editJourneyDelivery = function (journeyDelivery, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (journeyDelivery === null || journeyDelivery === undefined) {
                throw new Error('Required parameter journeyDelivery was null or undefined when calling editJourneyDelivery.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.put(this.basePath + "/journeyDeliveries", journeyDelivery, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        JourneyDeliveriesService.prototype.getJourneyDeliveries = function (skip, limit, orderBy, filter, deleted, metadata, idUser, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (skip === null || skip === undefined) {
                throw new Error('Required parameter skip was null or undefined when calling getJourneyDeliveries.');
            }
            if (limit === null || limit === undefined) {
                throw new Error('Required parameter limit was null or undefined when calling getJourneyDeliveries.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (skip !== undefined && skip !== null) {
                queryParameters = queryParameters.set('skip', skip);
            }
            if (limit !== undefined && limit !== null) {
                queryParameters = queryParameters.set('limit', limit);
            }
            if (orderBy !== undefined && orderBy !== null) {
                queryParameters = queryParameters.set('orderBy', orderBy);
            }
            if (filter !== undefined && filter !== null) {
                queryParameters = queryParameters.set('filter', filter);
            }
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (metadata !== undefined && metadata !== null) {
                queryParameters = queryParameters.set('metadata', metadata);
            }
            if (idUser !== undefined && idUser !== null) {
                queryParameters = queryParameters.set('idUser', idUser);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/journeyDeliveries", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        JourneyDeliveriesService.prototype.getJourneyDeliveryById = function (id, deleted, idUser, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling getJourneyDeliveryById.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (idUser !== undefined && idUser !== null) {
                queryParameters = queryParameters.set('idUser', idUser);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/journeyDeliveries/" + encodeURIComponent(String(id)), {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        JourneyDeliveriesService.ngInjectableDef = core.defineInjectable({ factory: function JourneyDeliveriesService_Factory() { return new JourneyDeliveriesService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: JourneyDeliveriesService, providedIn: "root" });
        JourneyDeliveriesService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], JourneyDeliveriesService);
        return JourneyDeliveriesService;
    }());

    var JourneysService = /** @class */ (function () {
        function JourneysService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        JourneysService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        JourneysService.prototype.addJourney = function (journey, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (journey === null || journey === undefined) {
                throw new Error('Required parameter journey was null or undefined when calling addJourney.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.post(this.basePath + "/journeys", journey, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        JourneysService.prototype.deleteJourney = function (id, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling deleteJourney.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.delete(this.basePath + "/journeys/" + encodeURIComponent(String(id)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        JourneysService.prototype.editJourney = function (journey, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (journey === null || journey === undefined) {
                throw new Error('Required parameter journey was null or undefined when calling editJourney.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.put(this.basePath + "/journeys", journey, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        JourneysService.prototype.getJourneyById = function (id, deleted, idUser, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling getJourneyById.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (idUser !== undefined && idUser !== null) {
                queryParameters = queryParameters.set('idUser', idUser);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/journeys/" + encodeURIComponent(String(id)), {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        JourneysService.prototype.getJourneys = function (skip, limit, orderBy, filter, deleted, metadata, idUser, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (skip === null || skip === undefined) {
                throw new Error('Required parameter skip was null or undefined when calling getJourneys.');
            }
            if (limit === null || limit === undefined) {
                throw new Error('Required parameter limit was null or undefined when calling getJourneys.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (skip !== undefined && skip !== null) {
                queryParameters = queryParameters.set('skip', skip);
            }
            if (limit !== undefined && limit !== null) {
                queryParameters = queryParameters.set('limit', limit);
            }
            if (orderBy !== undefined && orderBy !== null) {
                queryParameters = queryParameters.set('orderBy', orderBy);
            }
            if (filter !== undefined && filter !== null) {
                queryParameters = queryParameters.set('filter', filter);
            }
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (metadata !== undefined && metadata !== null) {
                queryParameters = queryParameters.set('metadata', metadata);
            }
            if (idUser !== undefined && idUser !== null) {
                queryParameters = queryParameters.set('idUser', idUser);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/journeys", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        JourneysService.ngInjectableDef = core.defineInjectable({ factory: function JourneysService_Factory() { return new JourneysService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: JourneysService, providedIn: "root" });
        JourneysService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], JourneysService);
        return JourneysService;
    }());

    var LocationsService = /** @class */ (function () {
        function LocationsService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        LocationsService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        LocationsService.prototype.addLocation = function (location, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (location === null || location === undefined) {
                throw new Error('Required parameter location was null or undefined when calling addLocation.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.post(this.basePath + "/locations", location, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        LocationsService.prototype.deleteLocation = function (id, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling deleteLocation.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.delete(this.basePath + "/locations/" + encodeURIComponent(String(id)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        LocationsService.prototype.editLocation = function (location, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (location === null || location === undefined) {
                throw new Error('Required parameter location was null or undefined when calling editLocation.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.put(this.basePath + "/locations", location, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        LocationsService.prototype.getLocationById = function (id, deleted, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling getLocationById.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/locations/" + encodeURIComponent(String(id)), {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        LocationsService.prototype.getLocations = function (skip, limit, orderBy, filter, deleted, metadata, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (skip === null || skip === undefined) {
                throw new Error('Required parameter skip was null or undefined when calling getLocations.');
            }
            if (limit === null || limit === undefined) {
                throw new Error('Required parameter limit was null or undefined when calling getLocations.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (skip !== undefined && skip !== null) {
                queryParameters = queryParameters.set('skip', skip);
            }
            if (limit !== undefined && limit !== null) {
                queryParameters = queryParameters.set('limit', limit);
            }
            if (orderBy !== undefined && orderBy !== null) {
                queryParameters = queryParameters.set('orderBy', orderBy);
            }
            if (filter !== undefined && filter !== null) {
                queryParameters = queryParameters.set('filter', filter);
            }
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (metadata !== undefined && metadata !== null) {
                queryParameters = queryParameters.set('metadata', metadata);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/locations", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        LocationsService.ngInjectableDef = core.defineInjectable({ factory: function LocationsService_Factory() { return new LocationsService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: LocationsService, providedIn: "root" });
        LocationsService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], LocationsService);
        return LocationsService;
    }());

    var MembershipsService = /** @class */ (function () {
        function MembershipsService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        MembershipsService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        MembershipsService.prototype.addMembership = function (membership, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (membership === null || membership === undefined) {
                throw new Error('Required parameter membership was null or undefined when calling addMembership.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.post(this.basePath + "/memberships", membership, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        MembershipsService.prototype.deleteMembership = function (id, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling deleteMembership.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.delete(this.basePath + "/memberships/" + encodeURIComponent(String(id)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        MembershipsService.prototype.editMembership = function (membership, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (membership === null || membership === undefined) {
                throw new Error('Required parameter membership was null or undefined when calling editMembership.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.put(this.basePath + "/memberships", membership, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        MembershipsService.prototype.getMemberships = function (skip, limit, orderBy, filter, deleted, metadata, idUser, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (skip === null || skip === undefined) {
                throw new Error('Required parameter skip was null or undefined when calling getMemberships.');
            }
            if (limit === null || limit === undefined) {
                throw new Error('Required parameter limit was null or undefined when calling getMemberships.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (skip !== undefined && skip !== null) {
                queryParameters = queryParameters.set('skip', skip);
            }
            if (limit !== undefined && limit !== null) {
                queryParameters = queryParameters.set('limit', limit);
            }
            if (orderBy !== undefined && orderBy !== null) {
                queryParameters = queryParameters.set('orderBy', orderBy);
            }
            if (filter !== undefined && filter !== null) {
                queryParameters = queryParameters.set('filter', filter);
            }
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (metadata !== undefined && metadata !== null) {
                queryParameters = queryParameters.set('metadata', metadata);
            }
            if (idUser !== undefined && idUser !== null) {
                queryParameters = queryParameters.set('idUser', idUser);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/memberships", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        MembershipsService.prototype.getMembershipsById = function (id, deleted, idUser, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling getMembershipsById.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (idUser !== undefined && idUser !== null) {
                queryParameters = queryParameters.set('idUser', idUser);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/memberships/" + encodeURIComponent(String(id)), {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        MembershipsService.ngInjectableDef = core.defineInjectable({ factory: function MembershipsService_Factory() { return new MembershipsService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: MembershipsService, providedIn: "root" });
        MembershipsService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], MembershipsService);
        return MembershipsService;
    }());

    var PasswordsService = /** @class */ (function () {
        function PasswordsService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        PasswordsService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        PasswordsService.prototype.changePassword = function (oldPassword, newPassword, userId, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (oldPassword === null || oldPassword === undefined) {
                throw new Error('Required parameter oldPassword was null or undefined when calling changePassword.');
            }
            if (newPassword === null || newPassword === undefined) {
                throw new Error('Required parameter newPassword was null or undefined when calling changePassword.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (oldPassword !== undefined && oldPassword !== null) {
                queryParameters = queryParameters.set('oldPassword', oldPassword);
            }
            if (newPassword !== undefined && newPassword !== null) {
                queryParameters = queryParameters.set('newPassword', newPassword);
            }
            if (userId !== undefined && userId !== null) {
                queryParameters = queryParameters.set('userId', userId);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/users/password/change", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        PasswordsService.prototype.changePasswordWithToken = function (token, password, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (token === null || token === undefined) {
                throw new Error('Required parameter token was null or undefined when calling changePasswordWithToken.');
            }
            if (password === null || password === undefined) {
                throw new Error('Required parameter password was null or undefined when calling changePasswordWithToken.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (password !== undefined && password !== null) {
                queryParameters = queryParameters.set('password', password);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/users/password/change/" + encodeURIComponent(String(token)), {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        PasswordsService.prototype.requestPassword = function (email, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (email === null || email === undefined) {
                throw new Error('Required parameter email was null or undefined when calling requestPassword.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (email !== undefined && email !== null) {
                queryParameters = queryParameters.set('email', email);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/users/password/forgot", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        PasswordsService.ngInjectableDef = core.defineInjectable({ factory: function PasswordsService_Factory() { return new PasswordsService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: PasswordsService, providedIn: "root" });
        PasswordsService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], PasswordsService);
        return PasswordsService;
    }());

    var UsersService = /** @class */ (function () {
        function UsersService(httpClient, basePath, configuration) {
            this.httpClient = httpClient;
            this.basePath = 'http://vamosalacarga.com.ar/backend/api/latest/';
            this.defaultHeaders = new http.HttpHeaders();
            this.configuration = new Configuration();
            if (basePath) {
                this.basePath = basePath;
            }
            if (configuration) {
                this.configuration = configuration;
                this.basePath = basePath || configuration.basePath || this.basePath;
            }
        }
        /**
         * @param consumes string[] mime-types
         * @return true: consumes contains 'multipart/form-data', false: otherwise
         */
        UsersService.prototype.canConsumeForm = function (consumes) {
            var e_1, _a;
            var form = 'multipart/form-data';
            try {
                for (var consumes_1 = __values(consumes), consumes_1_1 = consumes_1.next(); !consumes_1_1.done; consumes_1_1 = consumes_1.next()) {
                    var consume = consumes_1_1.value;
                    if (form === consume) {
                        return true;
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (consumes_1_1 && !consumes_1_1.done && (_a = consumes_1.return)) _a.call(consumes_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return false;
        };
        UsersService.prototype.addUser = function (user, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (user === null || user === undefined) {
                throw new Error('Required parameter user was null or undefined when calling addUser.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.post(this.basePath + "/users", user, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UsersService.prototype.deleteUsers = function (id, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling deleteUsers.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.delete(this.basePath + "/users/" + encodeURIComponent(String(id)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UsersService.prototype.editUser = function (user, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (user === null || user === undefined) {
                throw new Error('Required parameter user was null or undefined when calling editUser.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            // to determine the Content-Type header
            var consumes = [
                'application/json',
                'application/xml'
            ];
            var httpContentTypeSelected = this.configuration.selectHeaderContentType(consumes);
            if (httpContentTypeSelected != undefined) {
                headers = headers.set('Content-Type', httpContentTypeSelected);
            }
            return this.httpClient.put(this.basePath + "/users", user, {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UsersService.prototype.getUserById = function (id, deleted, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (id === null || id === undefined) {
                throw new Error('Required parameter id was null or undefined when calling getUserById.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/users/" + encodeURIComponent(String(id)), {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UsersService.prototype.getUsers = function (skip, limit, orderBy, filter, deleted, metadata, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (skip === null || skip === undefined) {
                throw new Error('Required parameter skip was null or undefined when calling getUsers.');
            }
            if (limit === null || limit === undefined) {
                throw new Error('Required parameter limit was null or undefined when calling getUsers.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (skip !== undefined && skip !== null) {
                queryParameters = queryParameters.set('skip', skip);
            }
            if (limit !== undefined && limit !== null) {
                queryParameters = queryParameters.set('limit', limit);
            }
            if (orderBy !== undefined && orderBy !== null) {
                queryParameters = queryParameters.set('orderBy', orderBy);
            }
            if (filter !== undefined && filter !== null) {
                queryParameters = queryParameters.set('filter', filter);
            }
            if (deleted !== undefined && deleted !== null) {
                queryParameters = queryParameters.set('deleted', deleted);
            }
            if (metadata !== undefined && metadata !== null) {
                queryParameters = queryParameters.set('metadata', metadata);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/users", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UsersService.prototype.login = function (email, password, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (email === null || email === undefined) {
                throw new Error('Required parameter email was null or undefined when calling login.');
            }
            if (password === null || password === undefined) {
                throw new Error('Required parameter password was null or undefined when calling login.');
            }
            var queryParameters = new http.HttpParams({ encoder: new CustomHttpUrlEncodingCodec() });
            if (email !== undefined && email !== null) {
                queryParameters = queryParameters.set('email', email);
            }
            if (password !== undefined && password !== null) {
                queryParameters = queryParameters.set('password', password);
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/users/login", {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UsersService.prototype.loginToken = function (token, observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            if (token === null || token === undefined) {
                throw new Error('Required parameter token was null or undefined when calling loginToken.');
            }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/users/login/" + encodeURIComponent(String(token)), {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UsersService.prototype.logout = function (observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            var headers = this.defaultHeaders;
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/users/logout", {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UsersService.prototype.verifyToken = function (observe, reportProgress) {
            if (observe === void 0) { observe = 'body'; }
            if (reportProgress === void 0) { reportProgress = false; }
            var headers = this.defaultHeaders;
            // authentication (appToken) required
            if (this.configuration.apiKeys["X_APP_ID"]) {
                headers = headers.set('X_APP_ID', this.configuration.apiKeys["X_APP_ID"]);
            }
            // authentication (userToken) required
            if (this.configuration.apiKeys["X_USER_KEY"]) {
                headers = headers.set('X_USER_KEY', this.configuration.apiKeys["X_USER_KEY"]);
            }
            // to determine the Accept header
            var httpHeaderAccepts = [
                'application/json',
                'application/xml'
            ];
            var httpHeaderAcceptSelected = this.configuration.selectHeaderAccept(httpHeaderAccepts);
            if (httpHeaderAcceptSelected != undefined) {
                headers = headers.set('Accept', httpHeaderAcceptSelected);
            }
            return this.httpClient.get(this.basePath + "/users/verifyToken", {
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            });
        };
        UsersService.ngInjectableDef = core.defineInjectable({ factory: function UsersService_Factory() { return new UsersService(core.inject(http.HttpClient), core.inject(BASE_PATH, 8), core.inject(Configuration, 8)); }, token: UsersService, providedIn: "root" });
        UsersService = __decorate([
            core.Injectable({
                providedIn: 'root'
            }),
            __param(1, core.Optional()), __param(1, core.Inject(BASE_PATH)), __param(2, core.Optional()),
            __metadata("design:paramtypes", [http.HttpClient, String, Configuration])
        ], UsersService);
        return UsersService;
    }());

    var APIS = [AccountEmailsService, AccountsService, CarriersService, DeliveriesService, EmailsService, HandedOversService, JourneyDeliveriesService, JourneysService, LocationsService, MembershipsService, PasswordsService, UsersService];


    (function (Memberships) {
        Memberships.RoleEnum = {
            VIEWER: 'VIEWER',
            EDITOR: 'EDITOR',
            ADMIN: 'ADMIN'
        };
    })(exports.Memberships || (exports.Memberships = {}));


    (function (Users) {
        Users.RoleEnum = {
            COMMON: 'COMMON',
            VIEWER: 'VIEWER',
            EDITOR: 'EDITOR',
            ADMIN: 'ADMIN'
        };
    })(exports.Users || (exports.Users = {}));

    var ApiModule = /** @class */ (function () {
        function ApiModule(parentModule, http) {
            if (parentModule) {
                throw new Error('ApiModule is already loaded. Import in your base AppModule only.');
            }
            if (!http) {
                throw new Error('You need to import the HttpClientModule in your AppModule! \n' +
                    'See also https://github.com/angular/angular/issues/20575');
            }
        }
        ApiModule_1 = ApiModule;
        ApiModule.forRoot = function (configurationFactory) {
            return {
                ngModule: ApiModule_1,
                providers: [{ provide: Configuration, useFactory: configurationFactory }]
            };
        };
        var ApiModule_1;
        ApiModule = ApiModule_1 = __decorate([
            core.NgModule({
                imports: [],
                declarations: [],
                exports: [],
                providers: [
                    AccountEmailsService,
                    AccountsService,
                    CarriersService,
                    DeliveriesService,
                    EmailsService,
                    HandedOversService,
                    JourneyDeliveriesService,
                    JourneysService,
                    LocationsService,
                    MembershipsService,
                    PasswordsService,
                    UsersService
                ]
            }),
            __param(0, core.Optional()), __param(0, core.SkipSelf()),
            __param(1, core.Optional()),
            __metadata("design:paramtypes", [ApiModule,
                http.HttpClient])
        ], ApiModule);
        return ApiModule;
    }());

    exports.APIS = APIS;
    exports.AccountEmailsService = AccountEmailsService;
    exports.AccountsService = AccountsService;
    exports.ApiModule = ApiModule;
    exports.BASE_PATH = BASE_PATH;
    exports.COLLECTION_FORMATS = COLLECTION_FORMATS;
    exports.CarriersService = CarriersService;
    exports.Configuration = Configuration;
    exports.DeliveriesService = DeliveriesService;
    exports.EmailsService = EmailsService;
    exports.HandedOversService = HandedOversService;
    exports.JourneyDeliveriesService = JourneyDeliveriesService;
    exports.JourneysService = JourneysService;
    exports.LocationsService = LocationsService;
    exports.MembershipsService = MembershipsService;
    exports.PasswordsService = PasswordsService;
    exports.UsersService = UsersService;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=singletonar-tlc-api-angular-client.umd.js.map
